# WorkProperties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**work_reference_number** | **str** |  | 
**permit_reference_number** | **str** |  | 
**promoter_organisation** | **str** |  | 
**promoter_swa_code** | **str** |  | 
**work_category** | [**WorkCategoryResponse**](WorkCategoryResponse.md) |  | 
**work_category_string** | **str** |  | 
**start_date** | **datetime** |  | 
**end_date** | **datetime** |  | 
**traffic_management_type** | [**TrafficManagementTypeResponse**](TrafficManagementTypeResponse.md) |  | 
**traffic_management_type_string** | **str** |  | 
**current_traffic_management_type** | [**TrafficManagementTypeResponse**](TrafficManagementTypeResponse.md) |  | [optional] 
**current_traffic_management_type_string** | **str** |  | [optional] 
**current_traffic_management_update_date** | **datetime** |  | [optional] 
**street** | **str** |  | 
**usrn** | **float** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**highway_authority** | **str** |  | 
**work_centre_point** | [**GeoJSONCentrePoint**](GeoJSONCentrePoint.md) |  | 
**permit_status** | [**PermitStatusResponse**](PermitStatusResponse.md) |  | 
**permit_status_string** | **str** |  | 
**industry_sector** | **AllOfWorkPropertiesIndustrySector** |  | [optional] 
**industry_sector_string** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

